@@ -21,7 +21,7 @@ show_help (void)
 {
   puts ("\
 Usage: shake [OPTION]... [FILE|DIRECTORY]...\n\
-Rewrite fragmented files, maybe improving performance (defragmenter).\n\
+Rewrite fragmented or misplaced files, maybe improving performance.\n\
 Read from standard input if there is no files in argv.\n\
 You have to mount your partition with user_xattr option.\n\
 \n\
@@ -42,7 +42,8 @@ You have to mount your partition with user_xattr option.\n\
   -v, --verbose		increase the verbosity level\n			\
   -V, --version		show version number and copyright\n\
   -X, --no-xattr	disable usage of xattr\n\
-Report bugs to <brice.arnould+shake@gmail.com>\
+Report bugs to <brice.arnould+shake@gmail.com> or at\n\
+http://savannah.nongnu.org/projects/shake\
 ");
 }
 
@@ -50,7 +51,7 @@ void
 show_version (void)
 {
   puts ("\
-Shake 0.26\n\
+Shake " VERSION "\n\
 Copyright (C) 2006 Brice Arnould.\n\
 Shake comes with ABSOLUTELY NO WARRANTY. You may redistribute copies of Shake\n\
 under the terms of the GNU General Public License. For more information about\n\
@@ -74,8 +75,8 @@ void
 show_reg (struct accused *a, struct law *l)
 {
   /* Show file status */
-  printf ("%i\t%i\t%i\t%i\t%i\t%i\t%i\t%s",
-	  a->ideal, a->start, a->end, a->fragc, a->crumbc,
+  printf ("%lli\t%lli\t%lli\t%i\t%i\t%i\t%i\t%s",
+	  a->ideal, a->start/1024, a->end/1024, a->fragc, a->crumbc,
 	  (int) (a->age / 3600 / 24), a->guilty, a->name);
   /* And, eventualy, list of frags and crumbs */
   if (l->verbosity > 2 && a->poslog && a->poslog[0] != -1)
@@ -83,8 +84,8 @@ show_reg (struct accused *a, struct law *l)
       uint n;
       putchar ('\t');
       for (n = 0; a->sizelog[n + 1] != -1; n++)
-	printf ("%i:%i,", a->poslog[n], a->sizelog[n]);
-      printf ("%i:%i\n", a->poslog[n], a->sizelog[n]);
+	printf ("%lli:%lli,", a->poslog[n]/1024, a->sizelog[n]/1024);
+      printf ("%lli:%lli\n", a->poslog[n]/1024, a->sizelog[n]/1024);
     }
   else
     putchar ('\n');
